==> gcloud-oauth-vue-0.1.0.tgz: package/src/grpc/token.js <==
import { Message } from 'element-ui'
import {MsgStatus} from './status.js'
import router from '../router/index'
import store from "../store/index"


/**  OAuth2.0 interceptor implementation */
const TokenUnaryInterceptor = function() {};

const TokenStreamInterceptor = function(){};


TokenUnaryInterceptor.prototype.intercept = async function(request, invoker) {

    // console.debug("request:",request.getRequestMessage());
    // console.debug("metadata:",request.getMetadata());
    const accessToken = await store.dispatch('user/accessToken');
  
    request.getMetadata()['Authorization'] = "Bearer "+ accessToken;
     // console.debug("metadata:",request.getMetadata());
    return invoker(request).catch(err=>{
      if (MsgStatus.UNAUTHENTICATED===err.code){
        router.push({path:"/login"});
        store.dispatch('user/resetToken');
      }else{
        Message({
          message: err.message,
          type: 'error',
          duration: 5 * 1000
        });
        console.log(err);
        throw err;
      }
    });
};

TokenStreamInterceptor.prototype.intercept = async function(request, invoker) {
   // console.debug("request:",request.getRequestMessage());
   // console.debug("metadata:",request.getMetadata());
   const accessToken = await store.dispatch('user/accessToken');
   request.getMetadata()['Authorization'] = "Bearer "+ accessToken;

  return invoker(request);
};

//const { OauthUnaryInterceptor,TokenUnaryInterceptor } = require('@/api/grpc_request');

const tokenOpts = {'unaryInterceptors' : [new TokenUnaryInterceptor()]};
const tokenStreamOpts = {'streamInterceptors' : [new TokenStreamInterceptor()]};

export {tokenOpts,tokenStreamOpts,TokenStreamInterceptor,TokenUnaryInterceptor};

==> gcloud-oauth-vue-0.1.18.tgz: package/src/grpc/token.js <==
import { Message } from 'element-ui'
import {MsgStatus} from './status.js'
import router from '../router/index'
import store from "../store/index"


/**  OAuth2.0 interceptor implementation */
const TokenUnaryInterceptor = function() {};

const TokenStreamInterceptor = function(){};


TokenUnaryInterceptor.prototype.intercept = async function(request, invoker) {

    // console.debug("request:",request.getRequestMessage());
    // console.debug("metadata:",request.getMetadata());
    const accessToken = await store.dispatch('user/accessToken');
  
    request.getMetadata()['Authorization'] = "Bearer "+ accessToken;
     // console.debug("metadata:",request.getMetadata());
    return invoker(request).catch(err=>{
      if (MsgStatus.UNAUTHENTICATED===err.code){
        router.push({path:"/login"});
        store.dispatch('user/resetToken');
      }else{
        Message({
          message: err.message,
          type: 'error',
          duration: 5 * 1000
        });
        console.log(err);
        throw err;
      }
    });
};

TokenStreamInterceptor.prototype.intercept = async function(request, invoker) {
   // console.debug("request:",request.getRequestMessage());
   // console.debug("metadata:",request.getMetadata());
   const accessToken = await store.dispatch('user/accessToken');
   request.getMetadata()['Authorization'] = "Bearer "+ accessToken;
   return invoker(request);
};

const tokenUnaryOpts = {'unaryInterceptors' : [new TokenUnaryInterceptor()]};
const tokenStreamOpts = {'streamInterceptors' : [new TokenStreamInterceptor()]};

const tokenOpts = {
  unaryInterceptors: [new TokenUnaryInterceptor()],
  streamInterceptors: [new TokenStreamInterceptor()]
};

export {tokenOpts,tokenUnaryOpts,tokenStreamOpts,TokenStreamInterceptor,TokenUnaryInterceptor};
